@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from datetime import timedelta
 from typing import Set
 
 from babelfish import Language
@@ -9,7 +10,7 @@ class Options:
 
     def __init__(self, config_path: str = None, languages: Set[Language] = None, tags: Set[str] = None,
                  encoding: str = None, overwrite=False, one_per_lang=True, max_workers: int = None,
-                 confidence=65, tesseract_width: int = None):
+                 confidence=65, tesseract_width: int = None, age: timedelta = None, srt_age: timedelta = None):
         self.config = Config.from_path(config_path) if config_path else Config()
         self.languages = languages or set()
         self.tags = tags or {'default'}
@@ -19,6 +20,8 @@ class Options:
         self.max_workers = max_workers
         self.confidence = confidence
         self.tesseract_width = tesseract_width
+        self.age = age
+        self.srt_age = srt_age
 
     def __repr__(self):
         return f'<{self.__class__.__name__} [{self}]>'
@@ -27,4 +30,5 @@ class Options:
         return (f'languages:{self.languages}, tags:{self.tags}, '
                 f'overwrite:{self.overwrite}, one_per_lang:{self.one_per_lang}, '
                 f'encoding:{self.encoding}, max_workers:{self.max_workers}, '
-                f'confidence:{self.confidence}, tesseract_width:{self.tesseract_width}')
+                f'confidence:{self.confidence}, tesseract_width:{self.tesseract_width}, '
+                f'age:{self.age}, srt_age:{self.srt_age}')
